translate.convert.oo2po.oo2po

Package translate :: Package convert :: Module oo2po :: Class oo2po |
[hide private]
[frames] | no frames]

# Class oo2po

source code

Instance Methods | [hide private]
__init__(self, sourcelanguage, targetlanguage, blankmsgstr=False, long_keys=False) construct an oo2po converter for the specified languages | source code
maketargetunit(self, part1, part2, translators_comment, key, subkey) makes a base unit (.po or XLIFF) out of a subkey of two parts | source code
convertelement(self, theoo) convert an oo element into a list of base units (.po or XLIFF) | source code
convertstore(self, theoofile, duplicatestyle="msgctxt") converts an entire oo file to a base class format (.po or XLIFF) | source code